@@ -181,6 +181,11 @@ export MYCLUSTER_JOB_NAME=$my_name
 export NUM_TASKS=$num_tasks
 export TASKS_PER_NODE=$tpn
 export THREADS_PER_TASK=$num_threads_per_task
+if [ "$${THREADS_PER_TASK}" -eq -1 ]; then
+    CPUS_PER_NODE=`echo $${SLURM_JOB_CPUS_PER_NODE}  | cut -d \( -f 1`
+    export THREADS_PER_TASK=`expr $${CPUS_PER_NODE} / $${TASKS_PER_NODE}`
+fi
+
 export NUM_NODES=$num_nodes
 export JOBID=$$SLURM_JOB_ID
 
@@ -301,7 +306,7 @@ def submit(script_name, immediate, depends_on = None, depends_on_always_run = Fa
         with os.popen('grep -- "SBATCH -J" '+script_name+' | sed \'s/#SBATCH//\'') as f:
             job = f.readline().rstrip()
 
-        cmd_line = 'salloc --exclusive '+nnodes+' '+partition+' '+ntasks+' '+project+' '+job+' srun -n 1 ./'+script_name
+        cmd_line = 'salloc --exclusive '+nnodes+' '+partition+' '+ntasks+' '+project+' '+job+' bash ./'+script_name
         print cmd_line
 
         with os.popen(cmd_line) as f:
